pub struct ElementPath { /* private fields */ }Expand description
ElementPath is aware of the FHIR data model and tracks its position in the tree.
It can be used to query type information of its current path.
Implementations
Sourceimpl ElementPath
impl ElementPath
pub fn new(fhir_release: FhirRelease) -> ElementPath
pub fn is_empty(&self) -> bool
pub fn current_element(&self) -> Option<&str>
pub fn current_element_is_resource(&self) -> bool
pub fn current_element_is_extension(&self) -> bool
pub fn current_element_is_primitive(&self) -> bool
pub fn current_element_is_sequence(&self) -> bool
pub fn current_element_is_boolean(&self) -> bool
pub fn current_element_is_integer(&self) -> bool
pub fn current_element_is_integer64(&self) -> bool
pub fn current_element_is_unsigned_integer(&self) -> bool
pub fn current_element_is_positive_integer(&self) -> bool
pub fn current_element_is_decimal(&self) -> bool
pub fn parent_element_is_resource(&self) -> bool
pub fn parent_element_is_boolean(&self) -> bool
pub fn parent_element_is_integer(&self) -> bool
pub fn parent_element_is_integer64(&self) -> bool
pub fn parent_element_is_unsigned_integer(&self) -> bool
pub fn parent_element_is_positive_integer(&self) -> bool
pub fn parent_element_is_decimal(&self) -> bool
pub fn push(&mut self, element: &str)
pub fn pop(&mut self)
pub fn children(&self) -> Option<&'static ElementSet>
pub fn position_of_child(&self, child: &str) -> usize