pub struct TypeHints {
pub type_paths: Map<&'static str, &'static str>,
pub array_paths: Set<&'static str>,
pub boolean_paths: Set<&'static str>,
pub integer_paths: Set<&'static str>,
pub unsigned_integer_paths: Set<&'static str>,
pub positive_integer_paths: Set<&'static str>,
pub decimal_paths: Set<&'static str>,
pub other_primitives_paths: Set<&'static str>,
pub content_reference_paths: Map<&'static str, &'static str>,
}
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
From<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.